@@ -58,6 +58,7 @@ class NamelistsCalculation(CalcJob):
             help='Use an additional node for special settings')
         spec.input('parent_folder', valid_type=(RemoteData, FolderData, SinglefileData), required=False,
             help='Use a local or remote folder as parent folder (for restarts and similar)')
+        # yapf: enable
 
     def _get_following_text(self):
         """Return any optional text that is to be written after the normal namelists in the input file.
@@ -79,7 +80,8 @@ class NamelistsCalculation(CalcJob):
                 if key in parameters[namelist]:
                     raise exceptions.InputValidationError(
                         "You cannot specify explicitly the '{}' key in the '{}' "
-                        'namelist.'.format(key, namelist))
+                        'namelist.'.format(key, namelist)
+                    )
             else:
                 parameters[namelist] = {}
             parameters[namelist][key] = value
@@ -107,7 +109,8 @@ class NamelistsCalculation(CalcJob):
             raise exceptions.InputValidationError(
                 'The following namelists are specified in parameters, but are '
                 'not valid namelists for the current type of calculation: '
-                '{}'.format(','.join(list(parameters.keys()))))
+                '{}'.format(','.join(list(parameters.keys())))
+            )
 
         return filtered
 
@@ -122,7 +125,7 @@ class NamelistsCalculation(CalcJob):
 
         file_lines = []
         for namelist_name, namelist in parameters.items():
-            file_lines.append('&{0}'.format(namelist_name))
+            file_lines.append(f'&{namelist_name}')
             for key, value in sorted(namelist.items()):
                 file_lines.append(convert_input_to_namelist_entry(key, value)[:-1])
             file_lines.append('/')
@@ -154,13 +157,13 @@ class NamelistsCalculation(CalcJob):
         else:
             parameters = {}
 
-
         # =================== NAMELISTS AND CARDS ========================
         try:
             namelists_toprint = settings.pop('NAMELISTS')
             if not isinstance(namelists_toprint, list):
                 raise exceptions.InputValidationError(
-                    "The 'NAMELISTS' value, if specified in the settings input node, must be a list of strings")
+                    "The 'NAMELISTS' value, if specified in the settings input node, must be a list of strings"
+                )
         except KeyError:  # list of namelists not specified; do automatic detection
             namelists_toprint = self._default_namelists
 
@@ -172,31 +175,32 @@ class NamelistsCalculation(CalcJob):
         with folder.open(input_filename, 'w') as infile:
             infile.write(file_content)
 
+        symlink = settings.pop('PARENT_FOLDER_SYMLINK', False)
+
         remote_copy_list = []
         local_copy_list = []
+        remote_symlink_list = []
+
+        ptr = remote_symlink_list if symlink else remote_copy_list
 
         # copy remote output dir, if specified
         parent_calc_folder = self.inputs.get('parent_folder', None)
         if parent_calc_folder is not None:
             if isinstance(parent_calc_folder, RemoteData):
                 parent_calc_out_subfolder = settings.pop('PARENT_CALC_OUT_SUBFOLDER', self._INPUT_SUBFOLDER)
-                remote_copy_list.append((
+                ptr.append((
                     parent_calc_folder.computer.uuid,
-                    os.path.join(parent_calc_folder.get_remote_path(), parent_calc_out_subfolder),
-                    self._OUTPUT_SUBFOLDER
+                    os.path.join(parent_calc_folder.get_remote_path(),
+                                 parent_calc_out_subfolder), self._OUTPUT_SUBFOLDER
                 ))
             elif isinstance(parent_calc_folder, FolderData):
                 for filename in parent_calc_folder.list_object_names():
-                    local_copy_list.append((
-                        parent_calc_folder.uuid,
-                        filename,
-                        os.path.join(self._OUTPUT_SUBFOLDER, filename)
-                    ))
+                    local_copy_list.append(
+                        (parent_calc_folder.uuid, filename, os.path.join(self._OUTPUT_SUBFOLDER, filename))
+                    )
             elif isinstance(parent_calc_folder, SinglefileData):
                 single_file = parent_calc_folder
-                local_copy_list.append(
-                    (single_file.uuid, single_file.filename, single_file.filename)
-                )
+                local_copy_list.append((single_file.uuid, single_file.filename, single_file.filename))
 
         codeinfo = datastructures.CodeInfo()
         codeinfo.cmdline_params = settings.pop('CMDLINE', [])
@@ -209,6 +213,7 @@ class NamelistsCalculation(CalcJob):
         calcinfo.codes_info = [codeinfo]
         calcinfo.local_copy_list = local_copy_list
         calcinfo.remote_copy_list = remote_copy_list
+        calcinfo.remote_symlink_list = remote_symlink_list
 
         # Retrieve by default the output file and the xml file
         calcinfo.retrieve_list = []
@@ -224,6 +229,6 @@ class NamelistsCalculation(CalcJob):
 
         if settings:
             unknown_keys = ', '.join(list(settings.keys()))
-            raise exceptions.InputValidationError('`settings` contained unexpected keys: {}'.format(unknown_keys))
+            raise exceptions.InputValidationError(f'`settings` contained unexpected keys: {unknown_keys}')
 
         return calcinfo
